Module blaxel.models.request_total_metric_request_total_per_code
================================================================

Classes
-------

`RequestTotalMetricRequestTotalPerCode()`
:   Number of requests for all resources globally per code
    
    Method generated by attrs for class RequestTotalMetricRequestTotalPerCode.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :